@@ -1,13 +1,17 @@
 package Pod::Weaver::Plugin::WordList;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use Moose;
 with 'Pod::Weaver::Role::AddTextToSection';
 with 'Pod::Weaver::Role::Section';
 
+use File::Slurper qw(write_text);
+use File::Temp qw(tempfile);
+use Perinci::Result::Format::Lite;
+
 sub _process_module {
     no strict 'refs';
 
@@ -15,15 +19,12 @@ sub _process_module {
 
     my $filename = $input->{filename};
 
-    # XXX handle dynamically generated module (if there is such thing in the
-    # future)
-    local @INC = ("lib", @INC);
-
     {
-        my $package_pm = $package;
-        $package_pm =~ s!::!/!g;
-        $package_pm .= ".pm";
-        require $package_pm;
+        # we need to load the munged version of module
+        my ($temp_fh, $temp_fname) = tempfile();
+        my ($file) = grep { $_->name eq $filename } @{ $input->{zilla}->files };
+        write_text($temp_fname, $file->content);
+        require $temp_fname;
     }
 
     my $wl_name = $package;
@@ -57,6 +58,26 @@ sub _process_module {
             });
     }
 
+    # add Statistics section
+    {
+        no strict 'refs';
+        my @pod;
+        my $stats = \%{"$package\::STATS"};
+        last unless keys %$stats;
+        my $str = Perinci::Result::Format::Lite::format(
+            [200,"OK",$stats], "text-pretty");
+        $str =~ s/^/ /gm;
+        push @pod, $str, "\n";
+
+        $self->add_text_to_section(
+            $document, join("", @pod), 'STATISTICS',
+            {
+                after_section => ['SYNOPSIS'],
+                before_section => 'DESCRIPTION',
+                ignore => 1,
+            });
+    }
+
     $self->log(["Generated POD for '%s'", $filename]);
 }
 
@@ -90,7 +111,7 @@ Pod::Weaver::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.02 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2016-01-13.
+This document describes version 0.03 of Pod::Weaver::Plugin::WordList (from Perl distribution Pod-Weaver-Plugin-WordList), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -107,6 +128,8 @@ it does the following:
 
 =item * Add a Synopsis section (it doesn't already exist) showing how to use the module
 
+=item * Add Statistics section showing statistics from C<%STATS> (which can be generated by DZP:WordList)
+
 =back
 
 =for Pod::Coverage ^(weave_section)$
